Skip to contents

Returns the time vector for epoched data relative to event onset.

Usage

epochTimes(x)

Arguments

x

An epoched PhysioExperiment object.

Value

Numeric vector of times in seconds relative to event onset (negative values represent pre-stimulus time).

References

Luck, S.J. (2014). "An Introduction to the Event-Related Potential Technique." 2nd ed. MIT Press.

See also

epochData() which creates the epoched data, averageEpochs() for epoch averaging, plotERP() for ERP visualization.