Skip to contents

Plots the observed log power spectrum for one channel together with the full specparam model and the aperiodic-only fit.

Usage

plotSpecparam(result, channel = 1)

Arguments

result

A specparam_result from specparam().

channel

Channel index or label to plot (default: 1).

Value

A ggplot object.

See also

Examples

if (FALSE) { # \dontrun{
sp <- specparam(make_pe_2d(n_time = 4000, sr = 250))
plotSpecparam(sp, channel = 1)
} # }